# Waylay Alarms Service
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated based on the 
Waylay Alarms OpenAPI specification (API version: 1.11.0)
For more information, please visit [the openapi specification](https://docs.waylay.io/openapi/public/redocly/alarms.html).

It consists of a plugin for the waylay-sdk-core package, and contains the Alarms api methods.
Note that the typed model classes for all path params, query params, body params and responses for each of the api methods are contained in a separate package called waylay-sdk-alarms-types.

## Requirements.
This package requires Python 3.9+.

## Installation
Typically this package is installed when installing the [waylay-sdk-core](https://pypi.org/project/waylay-sdk/) package to enable the service's functionality.
When the service api methods are required, waylay-sdk-alarms is included in:
- ```pip install waylay-sdk-core[alarms]``` to install `waylay-sdk-core` along with only this service, or
- ```pip install waylay-sdk-core[services]``` to install `waylay-sdk-core` along with all services.
When the typed models are required, both waylay-sdk-alarms and waylay-sdk-alarms-types are included in:
- ```pip install waylay-sdk-core[alarms,alarms-types]``` to install `waylay-sdk-core` along with only this service including the typed models, or
- ```pip install waylay-sdk-core[services,services-types]``` to install `waylay-sdk-core` along with all services along with the typed models.

## Usage

```python
from pprint import pprint

# Import the waylay-client from the waylay-sdk-core package
from waylay.sdk.client import WaylayClient
from waylay.sdk.api.api_exceptions import ApiError

# Intialize a waylay client instance
waylay_client = WaylayClient.from_profile()

# Note that the typed model classes for responses/parameters/... are only available when `waylay-sdk-alarms-types` is installed
from waylay.services.alarms.models.version_response import VersionResponse
try:
    # Get Service Information
    # calls `GET /alarms/v1`
    api_response = await waylay_client.alarms.about.get(
    )
    print("The response of alarms.about.get:\n")
    pprint(api_response)
except ApiError as e:
    print("Exception when calling alarms.about.get: %s\n" % e)
```


For more information, please visit the [Waylay API documentation](https://docs.waylay.io/#/api/?id=software-development-kits).